# Changelog

All notable changes to this project will be documented in this file.

## [unreleased]

### ⚙️ Tasks

- *(simple-rag:chore)* Bump

## [0.13.0] - 2025-01-03

### ⚙️ Tasks

- *(simple-rag:chore)* Changelog, version, pyproject toml

<!-- generated by git-cliff -->
